==> zoph_0.9.19.orig.tar.gz: zoph-v0.9.19/php/autoload.inc.php <==
<?php
/**
 * Class autoloader
 *
 * This file is part of Zoph.
 *
 * Zoph is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Zoph is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Zoph; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @package Zoph
 * @author Jason Geiger
 * @author Jeroen Roos
 */

/**
 * Autoload file
 * @param string filename to load
 */
function zophAutoload($file) {
    if (is_readable("php/" . $file)) {
        require_once $file;
    } else if (is_readable(settings::$php_loc . "/" . $file)) {
        require_once $file;
    } else {
        return false;
    }

}

/**
 * Autoload a class
 * @param string name of class to load
 */
function zophAutoloadClass($class) {
    $file="classes/" . str_replace("\\", "/", $class) . ".inc.php";
    return zophAutoload($file);
}

/**
 * Autoload an interface
 * @param string name of interface to load
 */
function zophAutoloadInterface($interface) {
    $file="interfaces/" . $interface . ".inc.php";
    return zophAutoload($file);
}

/**
 * Autoload a trait
 * @param string name of trait to load
 */
function zophAutoloadTrait($trait) {
    $file="traits/" . $trait . ".inc.php";
    return zophAutoload($file);
}

spl_autoload_register("zophAutoloadClass");
spl_autoload_register("zophAutoloadInterface");
spl_autoload_register("zophAutoloadTrait");

==> zoph_1.0.1.orig.tar.gz: zoph-v1.0.1/php/autoload.inc.php <==
<?php
/**
 * Class autoloader
 *
 * This file is part of Zoph.
 *
 * Zoph is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Zoph is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Zoph; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @package Zoph
 * @author Jason Geiger
 * @author Jeroen Roos
 */

/**
 * Autoload file
 * @param string filename to load
 */
function zophAutoload($file) {
    if (is_readable($file)) {
        require_once $file;
    } else if (is_readable("php/" . $file)) {
        require_once "php/" . $file;
    } else if (is_readable(settings::$php_loc . "/" . $file)) {
        require_once $file;
    } else {
        return false;
    }

}

/**
 * Autoload a class
 * @param string name of class to load
 */
function zophAutoloadClass($class) {
    $file="classes/" . str_replace("\\", "/", $class) . ".inc.php";
    return zophAutoload($file);
}

/**
 * Autoload an interface
 * @param string name of interface to load
 */
function zophAutoloadInterface($interface) {
    $file="interfaces/" . $interface . ".inc.php";
    return zophAutoload($file);
}

/**
 * Autoload a trait
 * @param string name of trait to load
 */
function zophAutoloadTrait($trait) {
    $file="traits/" . $trait . ".inc.php";
    return zophAutoload($file);
}
spl_autoload_register("zophAutoloadClass");
spl_autoload_register("zophAutoloadInterface");
spl_autoload_register("zophAutoloadTrait");
